module.exports = {
    "port":         8080, //!!! Should be 80
    "logDir":       "/var/log/nps",
    "log": {
        "appenders": {
            "console": { "type": "console", "pattern": "[%d] [%p] %c - %m" },
        },
        "categories": {
            "default": {
                "appenders": ["console"],
                "level": "INFO"     // Log Levels are DEBUG, INFO, WARN and ERROR
            }
        },
        "replaceConsole": true
    },
    "tempDir":     "/tmp/nps",
    "uploadDir":    "uploads",
    "backupDir":    "backups",
    "pluginDirs":    ["node_modules", "plugins"],
}